import json
import larrydata
import boto3


_client = None
# A local instance of the boto3 session to use
_session = None


def session():
    """
    Retrieves the current boto3 session for this module
    :return: Boto3 session
    """
    global _session
    if _session is None:
        _session = boto3.session.Session()
    return _session


def set_session_parameters(aws_access_key_id=None,
                           aws_secret_access_key=None,
                           aws_session_token=None,
                           region_name=None,
                           profile_name=None):
    """
    Sets the boto3 session for this module to use a specified configuration state.
    :param aws_access_key_id: AWS access key ID
    :param aws_secret_access_key: AWS secret access key
    :param aws_session_token: AWS temporary session token
    :param region_name: Default region when creating new connections
    :param profile_name: The name of a profile to use
    :return: None
    """
    global _session
    _session = boto3.session.Session(**larrydata.copy_non_null_keys(locals()))


def client():
    global _client
    if _client is None:
        _client = session().client('sqs')
    return _client


def send_message(destination, message):
    if type(message) == dict:
        message = json.dumps(message)
    sqs = client()
    return sqs.send_message(QueueUrl=destination, MessageBody=message)
